@@ -5,6 +5,7 @@ use warnings;
 use parent 'PAGI::Middleware';
 use Future::AsyncAwait;
 use Digest::SHA qw(sha256_hex);
+use PAGI::Utils::Random qw(secure_random_bytes);
 
 =head1 NAME
 
@@ -52,9 +53,11 @@ Secret key for session ID generation and validation.
 
 Name of the session cookie.
 
-=item * cookie_options (default: { httponly => 1, path => '/' })
+=item * cookie_options (default: { httponly => 1, path => '/', samesite => 'Lax' })
 
-Options for the session cookie.
+Options for the session cookie. For production HTTPS deployments,
+add C<< secure => 1 >> to prevent the cookie from being sent over
+plain HTTP.
 
 =item * expire (default: 3600)
 
@@ -127,6 +130,7 @@ sub _init {
     $self->{cookie_options} = $config->{cookie_options} // {
         httponly => 1,
         path     => '/',
+        samesite => 'Lax',
     };
     $self->{expire} = $config->{expire} // 3600;
     $self->{store} = $config->{store};
@@ -216,36 +220,11 @@ sub _generate_session_id {
     my ($self) = @_;
 
     # Use cryptographically secure random bytes
-    my $random = unpack('H*', _secure_random_bytes(16));
+    my $random = unpack('H*', secure_random_bytes(16));
     my $time = time();
     return sha256_hex("$random-$time-$self->{secret}");
 }
 
-sub _secure_random_bytes {
-    my ($length) = @_;
-
-    # Try /dev/urandom first (Unix)
-    if (open my $fh, '<:raw', '/dev/urandom') {
-        my $bytes;
-        read($fh, $bytes, $length);
-        close $fh;
-        return $bytes if defined $bytes && length($bytes) == $length;
-    }
-
-    # Fallback: use Crypt::URandom if available
-    if (eval { require Crypt::URandom; 1 }) {
-        return Crypt::URandom::urandom($length);
-    }
-
-    # Last resort: warn and use less secure method
-    warn "PAGI::Middleware::Session: No secure random source available, using fallback\n";
-    my $bytes = '';
-    for (1..$length) {
-        $bytes .= chr(int(rand(256)));
-    }
-    return $bytes;
-}
-
 sub _valid_session_id {
     my ($self, $id) = @_;
 
